#!/bin/bash
#--------------------------------------------
# FFMPEG COMMON
# --------------
# provides the standard definitions for the
# collection of FFMPEG usage scripts.
#--------------------------------------------
pid=$(getpid)
# -------------------------------------------
# PROGRAM CONTENT FORMAT configuration
# -------------------------------------------
pixels="yuv420p"
mpegaudio="mp3"
mpegaudio="aac"
h264format="-codec:v h264 -pix_fmt $pixels -codec:a $mpegaudio -f mpegts"
h265format="-codec:v hevc -codec:a $mpegaudio -f mpegts"
mpgformat=$h264format
oggformat="-codec:v libtheora -codec:a libvorbis -f ogg"

# -------------------------------------------
# the host name of the deployed stream source
# -------------------------------------------
streamorigin=$1
password=$2
localhost=$3
orientation=$3
if [ -z "$orientation" ]; then
	orientation="LANDSCAPE"
fi
if [ "$orientation" == "LANDSCAPE" ]; then
scale1920="1920x1080"
scale1024="1024x764"
scale800="800x600"
scale720="720x540"
scale640="640x480"
scale560="560x420"
scale480="480x360"
scale400="400x300"
scale320="320x200"
scale160="160x100"
else
scale1920="1080x1920"
scale1024="764x1024"
scale800="600x800"
scale720="540x720"
scale640="480x640"
scale560="420x560"
scale480="360x480"
scale400="300x400"
scale320="200x320"
scale160="100x160"
fi
basescale=$scale800
mpegscale="-s:v "${basescale}
mpegscale=

aspectratio="16:9"
mpegaspect="-aspect:0 "${aspectratio}
mpegaspect=
copy="-codec:v copy -codec:a copy"

# -------------------------------------------
# The TCP port for communication between the
# ONSITE streamer and the CLOUD stream source
# -------------------------------------------
tcpport=8185
tcpinput="-i tcp://0.0.0.0:$tcpport?listen"
tcpoutput="-pixel_format $pixels tcp://$streamorigin:$tcpport"
tcpformat=$mpgformat

# -------------------------------------------
# HTTP Live Streaming Configuration
# -------------------------------------------
hlshost=$streamorigin
hlspath="stream/hls"
hlsport=80
hlsformat="$mpgformat $mpegscale $mpegaspect "
hlsoption="-f hls -hls_time 5 -hls_list_size 8 -hls_allow_cache 0 -hls_flags append_list -hls_flags delete_segments"
hlsvoption="-f hls -hls_time 5 -hls_list_size 0 -hls_allow_cache 0 -hls_flags append_list "
hlsmanifest="out.m3u8"
hlsinput="-f hls -i https://$hlshost/$hlspath/$hlsmanifest"
hlsoutput="$hlsoption $hlspath/$hlsmanifest"
hlsvodoutput="$hlsvoption $hlspath/$hlsmanifest"
hlsbaseurl="-hls_base_url https://$hlshost/$hlspath/"

# -------------------------------------------
# DASH Live Streaming Configuration
# -------------------------------------------
dashhost=$streamorigin
dashpath="stream/dash"
dashroot=/home/cosacs/$dashpath
dashport=80
dashformat="-map 0 -map 0 -codec:v h264 -pix_fmt $pixels -codec:a aac "
dashmanifest="out.mpd"
dash1scale="-s:v:0 "${basescale}
dash2scale="-s:v:1 "${basescale}
dash3scale="-s:v:2 "${basescale}
dash1scale=
dash2scale=
dash3scale=
dash1aspect="-aspect:0 "${aspectratio}
dash2aspect="-aspect:1 "${aspectratio}
dash3aspect="-aspect:2 "${aspectratio}
dash1profile="-profile:v:0 main"
dash2profile="-profile:v:1 baseline"
dash3profile="-profile:v:1 baseline"
dashv1="-b:v:0 800k "${dash1scale}" "${dash1profile}" "${dash1aspect}" "
dashv2="-b:v:1 300k "${dash2scale}" "${dash2profile}" "${dash1aspect}" "
dashv3="-b:v:2 100k "${dash3scale}" "${dash3profile}" "${dash1aspect}" "
dasho1="-bf 1 -keyint_min 120 -g 120 -sc_threshold 0 -b_strategy 0"
dasha2="-ar:a:1 22050 "
dasho2="-use_timeline 1 -use_template 1 -seg_duration 1 -window_size 10"
dashox2="-use_timeline 1 -use_template 1 -seg_duration 1 -window_size 0"
dasho3="-use_timeline 1 -use_template 1 -seg_duration 1 -window_size 0"
dashad="-adaptation_sets \"id=0,streams=v id=1,streams=a\""
dashinput="-i https://$dashhost/$dashpath/$dashmanifest"
dashoutput="$dashv1 $dashv2 $dasho1 $dasha2 $dasho2 -f dash $dashpath/$dashmanifest"
dashvodoutput="$dashv1 $dashv2 $dasho1 $dasha2 $dasho3 -f dash $dashpath/$dashmanifest"

# ----------------
# Smooth Streaming 
# ----------------
sstream="-map 0 -f segment -segment_list stream/out.m3u8  -segment_list_flags +live -segment_time 10 stream/out%03d.ts"
# -------------------------------------------
# ICECAST Streaming Configuration
# -------------------------------------------
icehost=localhost
iceport=8000
icepath=stream
icename=SoundStreet
icetype="video/ogg"
iceformat="-pixel_format $pixels $oggformat $scale $mpegaspect"
icecastoutput="-content_type $icetype -ice_name $icename -password $password icecast://$icehost:$iceport/$icepath"

# -------------------------------------------
# WINDOWS MEDIA FORMAT Configuration
# -------------------------------------------
winhost=localhost
winport=8180
winpath="stream.ffm"
winformat=mpgformat
windowsoutput="http://$winhost:$winport/$winpath"

# -------------------------------------------
# DECKLINK Input Configuration
# -------------------------------------------
decklink="-channels 2 -audio_input embedded -format_code Hp25 -f decklink -i \"DeckLink Mini Capture\""

# -------------------------------------------
# DISK FILE output configuration
# -------------------------------------------
diskdump="-bxxx output.avi.$pid"

#-----------
#end of file
#-----------

